==> haskell-bloomfilter-2.0.1.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bloomfilter.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bloomfilter
version: 2.0.1.0
id: bloomfilter-2.0.1.0-5UPRw8n3jd54bgljz0xmUx
key: bloomfilter-2.0.1.0-5UPRw8n3jd54bgljz0xmUx
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: provisional
homepage: https://github.com/bos/bloomfilter
synopsis: Pure and impure Bloom Filter implementations.
description:
    Pure and impure Bloom Filter implementations.
category: Data
abi: e43c8d506487e1010e1224a306afcbe1
exposed: True
exposed-modules:
    Data.BloomFilter Data.BloomFilter.Easy Data.BloomFilter.Hash
    Data.BloomFilter.Mutable
hidden-modules: Data.BloomFilter.Array
                Data.BloomFilter.Mutable.Internal Data.BloomFilter.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/bloomfilter-2.0.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/bloomfilter-2.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/bloomfilter-2.0.1.0
hs-libraries: HSbloomfilter-2.0.1.0-5UPRw8n3jd54bgljz0xmUx
include-dirs: /usr/lib/ghc-8.4.3/site-local/bloomfilter-2.0.1.0/include
includes:
    lookup3.h
depends:
    array-0.5.2.0 base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-bloomfilter/html/bloomfilter.haddock
haddock-html: /usr/share/doc/haskell-bloomfilter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bloomfilter-2.0.1.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bloomfilter.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bloomfilter
version: 2.0.1.0
id: bloomfilter-2.0.1.0-8BSovSPMnn3KBOOym3n0lP
key: bloomfilter-2.0.1.0-8BSovSPMnn3KBOOym3n0lP
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: provisional
homepage: https://github.com/bos/bloomfilter
synopsis: Pure and impure Bloom Filter implementations.
description:
    Pure and impure Bloom Filter implementations.
category: Data
abi: d14c0aaaf188d9787690242f3e9cba08
exposed: True
exposed-modules:
    Data.BloomFilter Data.BloomFilter.Easy Data.BloomFilter.Hash
    Data.BloomFilter.Mutable
hidden-modules: Data.BloomFilter.Array
                Data.BloomFilter.Mutable.Internal Data.BloomFilter.Util
import-dirs: /usr/lib/ghc-8.6.1/site-local/bloomfilter-2.0.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/bloomfilter-2.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/bloomfilter-2.0.1.0
hs-libraries: HSbloomfilter-2.0.1.0-8BSovSPMnn3KBOOym3n0lP
include-dirs: /usr/lib/ghc-8.6.1/site-local/bloomfilter-2.0.1.0/include
includes:
    lookup3.h
depends:
    array-0.5.2.0 base-4.12.0.0 bytestring-0.10.8.2 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-bloomfilter/html/bloomfilter.haddock
haddock-html: /usr/share/doc/haskell-bloomfilter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
